@@ -3,6 +3,7 @@ from flask import Flask
 from flask_regiment import InstaLog
 from dotenv import load_dotenv
 load_dotenv()
+from simple_blueprint import bp
 
 instalog = InstaLog()
 print("instalog: loaded")
@@ -12,7 +13,6 @@ def create_app(test_config=None):
     # create and configure the app
     app = Flask(__name__, instance_relative_config=True)
     app.config.from_mapping(
-        SECRET_KEY='dev',
         INSTALOG_API_KEY=os.getenv('API_KEY'),
         INSTALOG_API_SECRET_KEY=os.getenv('API_SECRET_KEY'),
         INSTALOG_META_DATA={
@@ -30,6 +30,8 @@ def create_app(test_config=None):
     app.instalog.log_info("custom log from flask")
     print("instalog: custom log sent")
 
+    app.register_blueprint(bp, url_prefix='/bp')
+
     # a simple page that says hello
     @app.route('/')
     def hello():
